@@ -3,7 +3,7 @@
 using namespace xorg::testing;
 
 /**
- * @example xorg-gtest.cpp
+ * @example xorg-gtest-example.cpp
  *
  * This is an example for using the fixture
  * xorg::testing::Test for your own tests. Please
@@ -13,6 +13,6 @@ using namespace xorg::testing;
  */
 TEST_F(Test, DummyXorgServerTest) {
 
-  EXPECT_NE(0, DefaultRootWindow(Display()));
+  EXPECT_NE((Window)None, DefaultRootWindow(Display()));
 
 }
